from distutils.core import setup

setup(
	name = 'svm_smo',
	version = '1.0.0',
	py_modules = ['svm_smo'],
	author = 'chenliyu',
	author_email = '2572065090@qq.com',
	url = 'http://pypi.python.org/ ',
	description = 'a simplfied version and a full version of implimention of svm using smo in python,and a test of linear and rbf',
)

